@@ -16,7 +16,7 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2006 Dominic Lachowicz <cinamod@hotmail.com>
-// Copyright (C) 2007-2008, 2010, 2011, 2017-2022, 2024 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2007-2008, 2010, 2011, 2017-2022, 2024, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2009 Jan Jockusch <jan@jockusch.de>
 // Copyright (C) 2010, 2013 Hib Eris <hib@hiberis.nl>
 // Copyright (C) 2010 Kenneth Berland <ken@hero.com>
@@ -33,7 +33,9 @@
 // Copyright (C) 2019, 2021 Oliver Sander <oliver.sander@tu-dresden.de>
 // Copyright (C) 2021 William Bader <williambader@hotmail.com>
 // Copyright (C) 2022 kVdNi <kVdNi@waqa.eu>
-// Copyright (C) 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2025, 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2025 Hagen Möbius <hagen.moebius@googlemail.com>
+// Copyright (C) 2026 Ojas Maheshwari <workonlyojas@gmail.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -49,11 +51,8 @@
 #include "parseargs.h"
 #include "printencodings.h"
 #include "goo/GooString.h"
-#include "goo/gmem.h"
 #include "GlobalParams.h"
 #include "Object.h"
-#include "Stream.h"
-#include "Array.h"
 #include "Dict.h"
 #include "XRef.h"
 #include "Catalog.h"
@@ -70,7 +69,6 @@
 #include <iomanip>
 #include "Win32Console.h"
 #include "DateInfo.h"
-#include <cfloat>
 
 static void printInfoString(FILE *f, Dict *infoDict, const char *key, const char *text1, const char *text2, const UnicodeMap *uMap);
 static void printInfoDate(FILE *f, Dict *infoDict, const char *key, const char *text1, const char *text2);
@@ -163,6 +161,15 @@ static std::string myXmlTokenReplace(const char *inString)
     return myString;
 }
 
+static constexpr EndOfLineKind defaultEndOfLine()
+{
+#ifdef _WIN32
+    return eolDOS;
+#else
+    return eolUnix;
+#endif
+}
+
 int main(int argc, char *argv[])
 {
     std::unique_ptr<PDFDoc> doc;
@@ -172,7 +179,7 @@ int main(int argc, char *argv[])
     const UnicodeMap *uMap;
     Object info;
     bool ok;
-    EndOfLineKind textEOL = TextOutputDev::defaultEndOfLine();
+    EndOfLineKind textEOL = defaultEndOfLine();
 
     Win32Console win32Console(&argc, &argv);
 
@@ -246,7 +253,7 @@ int main(int argc, char *argv[])
         userPW = GooString(userPassword);
     }
 
-    if (fileName.cmp("-") == 0) {
+    if (fileName.compare("-") == 0) {
         fileName = GooString("fd://0");
     }
 
@@ -267,7 +274,7 @@ int main(int argc, char *argv[])
     // construct text file name
     if (argc == 3) {
         textFileName = std::make_unique<GooString>(argv[2]);
-    } else if (fileName.cmp("fd://0") == 0) {
+    } else if (fileName.compare("fd://0") == 0) {
         error(errCommandLine, -1, "You have to provide an output filename when reading from stdin.");
         return 99;
     } else {
@@ -294,7 +301,7 @@ int main(int argc, char *argv[])
 
     // write HTML header
     if (htmlMeta) {
-        if (!textFileName->cmp("-")) {
+        if (!textFileName->compare("-")) {
             f = stdout;
         } else {
             if (!(f = fopen(textFileName->c_str(), "wb"))) {
@@ -354,7 +361,7 @@ int main(int argc, char *argv[])
 
         if (tsvMode) {
             TextOutputDev textOut(nullptr, physLayout, fixedPitch, rawOrder, htmlMeta, discardDiag);
-            if (!textFileName->cmp("-")) {
+            if (!textFileName->compare("-")) {
                 f = stdout;
             } else {
                 if (!(f = fopen(textFileName->c_str(), "wb"))) {
@@ -392,7 +399,7 @@ int main(int argc, char *argv[])
 
     // write end of HTML file
     if (htmlMeta) {
-        if (!textFileName->cmp("-")) {
+        if (!textFileName->compare("-")) {
             f = stdout;
         } else {
             if (!(f = fopen(textFileName->c_str(), "ab"))) {
@@ -497,10 +504,9 @@ static void printLine(FILE *f, const TextLine *line)
             lineYMax = yMax;
         }
 
-        GooString *wordText = word->getText();
+        const std::unique_ptr<std::string> wordText = word->getText();
         const std::string myString = myXmlTokenReplace(wordText->c_str());
         wordXML << "          <word xMin=\"" << xMin << "\" yMin=\"" << yMin << "\" xMax=\"" << xMax << "\" yMax=\"" << yMax << "\">" << myString << "</word>\n";
-        delete wordText;
     }
     fprintf(f, "        <line xMin=\"%f\" yMin=\"%f\" xMax=\"%f\" yMax=\"%f\">\n", lineXMin, lineYMin, lineXMax, lineYMax);
     fputs(wordXML.str().c_str(), f);
@@ -539,15 +545,10 @@ void printDocBBox(FILE *f, PDFDoc *doc, TextOutputDev *textOut, int first, int l
 
 void printTSVBBox(FILE *f, PDFDoc *doc, TextOutputDev *textOut, int first, int last)
 {
-    double xMin = 0, yMin = 0, xMax = 0, yMax = 0;
     const TextFlow *flow;
     const TextBlock *blk;
     const TextLine *line;
     const TextWord *word;
-    int blockNum = 0;
-    int lineNum = 0;
-    int flowNum = 0;
-    int wordNum = 0;
     const int pageLevel = 1;
     const int blockLevel = 3;
     const int lineLevel = 4;
@@ -561,22 +562,30 @@ void printTSVBBox(FILE *f, PDFDoc *doc, TextOutputDev *textOut, int first, int l
         const double wid = useCropBox ? doc->getPageCropWidth(page) : doc->getPageMediaWidth(page);
         const double hgt = useCropBox ? doc->getPageCropHeight(page) : doc->getPageMediaHeight(page);
 
-        fprintf(f, "%d\t%d\t%d\t%d\t%d\t%d\t%f\t%f\t%f\t%f\t%d\t###PAGE###\n", pageLevel, page, flowNum, blockNum, lineNum, wordNum, xMin, yMin, wid, hgt, metaConf);
+        fprintf(f, "%d\t%d\t%d\t%d\t%d\t%d\t%f\t%f\t%f\t%f\t%d\t###PAGE###\n", pageLevel, page, 0, 0, 0, 0, 0.0, 0.0, wid, hgt, metaConf);
         doc->displayPage(textOut, page, resolution, resolution, 0, !useCropBox, useCropBox, false);
 
+        double xMin = 0, yMin = 0, xMax = 0, yMax = 0;
+        int flowNum = 0;
+
         for (flow = textOut->getFlows(); flow; flow = flow->getNext()) {
             // flow->getBBox(&xMin, &yMin, &xMax, &yMax);
             // fprintf(f, "%d\t%d\t%d\t%d\t%d\t%f\t%f\t%f\t%f\t\n", page,flowNum,blockNum,lineNum,wordNum,xMin,yMin,wid, hgt);
 
+            int blockNum = 0;
+
             for (blk = flow->getBlocks(); blk; blk = blk->getNext()) {
+                int lineNum = 0;
+
                 blk->getBBox(&xMin, &yMin, &xMax, &yMax);
-                fprintf(f, "%d\t%d\t%d\t%d\t%d\t%d\t%f\t%f\t%f\t%f\t%d\t###FLOW###\n", blockLevel, page, flowNum, blockNum, lineNum, wordNum, xMin, yMin, xMax - xMin, yMax - yMin, metaConf);
+                fprintf(f, "%d\t%d\t%d\t%d\t%d\t%d\t%f\t%f\t%f\t%f\t%d\t###FLOW###\n", blockLevel, page, flowNum, blockNum, lineNum, 0, xMin, yMin, xMax - xMin, yMax - yMin, metaConf);
 
                 for (line = blk->getLines(); line; line = line->getNext()) {
+                    int wordNum = 0;
 
                     double lxMin = 1E+37, lyMin = 1E+37;
                     double lxMax = 0, lyMax = 0;
-                    GooString *lineWordsBuffer = new GooString();
+                    auto *lineWordsBuffer = new GooString();
 
                     for (word = line->getWords(); word; word = word->getNext()) {
                         word->getBBox(&xMin, &yMin, &xMax, &yMax);
@@ -593,8 +602,8 @@ void printTSVBBox(FILE *f, PDFDoc *doc, TextOutputDev *textOut, int first, int l
                             lyMax = yMax;
                         }
 
-                        lineWordsBuffer->appendf("{0:d}\t{1:d}\t{2:d}\t{3:d}\t{4:d}\t{5:d}\t{6:.2f}\t{7:.2f}\t{8:.2f}\t{9:.2f}\t{10:d}\t{11:t}\n", wordLevel, page, flowNum, blockNum, lineNum, wordNum, xMin, yMin, xMax - xMin, yMax - yMin,
-                                                 wordConf, word->getText());
+                        lineWordsBuffer->appendf("{0:d}\t{1:d}\t{2:d}\t{3:d}\t{4:d}\t{5:d}\t{6:.2f}\t{7:.2f}\t{8:.2f}\t{9:.2f}\t{10:d}\t{11:s}\n", wordLevel, page, flowNum, blockNum, lineNum, wordNum, xMin, yMin, xMax - xMin, yMax - yMin,
+                                                 wordConf, word->getText()->c_str());
                         wordNum++;
                     }
 
@@ -602,16 +611,12 @@ void printTSVBBox(FILE *f, PDFDoc *doc, TextOutputDev *textOut, int first, int l
                     fprintf(f, "%d\t%d\t%d\t%d\t%d\t%d\t%f\t%f\t%f\t%f\t%d\t###LINE###\n", lineLevel, page, flowNum, blockNum, lineNum, 0, lxMin, lyMin, lxMax - lxMin, lyMax - lyMin, metaConf);
                     fprintf(f, "%s", lineWordsBuffer->c_str());
                     delete lineWordsBuffer;
-                    wordNum = 0;
                     lineNum++;
                 }
-                lineNum = 0;
                 blockNum++;
             }
-            blockNum = 0;
             flowNum++;
         }
-        flowNum = 0;
     }
 }
 
@@ -623,19 +628,18 @@ void printWordBBox(FILE *f, PDFDoc *doc, TextOutputDev *textOut, int first, int
         double hgt = useCropBox ? doc->getPageCropHeight(page) : doc->getPageMediaHeight(page);
         fprintf(f, "  <page width=\"%f\" height=\"%f\">\n", wid, hgt);
         doc->displayPage(textOut, page, resolution, resolution, 0, !useCropBox, useCropBox, false);
-        std::unique_ptr<TextWordList> wordlist = textOut->makeWordList();
-        const int word_length = wordlist != nullptr ? wordlist->getLength() : 0;
-        TextWord *word;
-        double xMinA, yMinA, xMaxA, yMaxA;
-        if (word_length == 0) {
-            fprintf(stderr, "no word list\n");
-        }
+        const std::unique_ptr<TextWordList> wordlist = textOut->makeWordList();
+        const std::vector<TextWord *> &words = wordlist->getWords();
 
-        for (int i = 0; i < word_length; ++i) {
-            word = wordlist->get(i);
-            word->getBBox(&xMinA, &yMinA, &xMaxA, &yMaxA);
-            const std::string myString = myXmlTokenReplace(word->getText()->c_str());
-            fprintf(f, "    <word xMin=\"%f\" yMin=\"%f\" xMax=\"%f\" yMax=\"%f\">%s</word>\n", xMinA, yMinA, xMaxA, yMaxA, myString.c_str());
+        if (words.empty()) {
+            fprintf(stderr, "no word list\n");
+        } else {
+            for (const TextWord *word : words) {
+                double xMinA, yMinA, xMaxA, yMaxA;
+                word->getBBox(&xMinA, &yMinA, &xMaxA, &yMaxA);
+                const std::string myString = myXmlTokenReplace(word->getText()->c_str());
+                fprintf(f, "    <word xMin=\"%f\" yMin=\"%f\" xMax=\"%f\" yMax=\"%f\">%s</word>\n", xMinA, yMinA, xMaxA, yMaxA, myString.c_str());
+            }
         }
         fprintf(f, "  </page>\n");
     }
